itkwasm-image-io
=======

> Input and output for scientific and medical image file formats.

[![itkwasm-image-io version](https://badge.fury.io/py/itkwasm_image_io.svg)](https://pypi.org/project/itkwasm_image_io/)

## Installation

::::{tab-set}

:::{tab-item} System
```shell
pip install itkwasm-image-io
```
:::

:::{tab-item} Browser
In Pyodide, e.g. the [Pyodide REPL](https://pyodide.org/en/stable/console.html) or [JupyterLite](https://jupyterlite.readthedocs.io/en/latest/try/lab),

```python
import micropip
await micropip.install('itkwasm-image-io')
:::

::::

```{toctree}
:hidden:
:maxdepth: 3
:caption: 📖 Reference

apidocs/index.rst
itkwasm docs <https://itkwasm.readthedocs.io/>
```